.widget .calendar{padding:1rem}.widget .calendar .event{font-size:.95em}.widget .calendar .upcoming-event{text-align:center;margin-bottom:1.5rem;font-size:1.2em}.widget .calendar .upcoming-event .summary{text-transform:uppercase;font-size:1.3em}
