<script type="text/x-template" id="tmpl-tv-samsung-ws">
    <div class="tv-samsung-ws-container">
        <div class="controls" tabindex="1">
            <div class="row section">
                <div class="col-4">
                    <button @click="home" value="home">
                        <i class="fas fa-home"></i>
                    </button>
                </div>
                <div class="col-4">&nbsp;</div>
                <div class="col-4">
                    <button @click="power" class="power" value="power">
                        <i class="fas fa-power-off"></i>
                    </button>
                </div>
            </div>

            <div class="row rows section">
                <div class="row">
                    <div class="col-4">
                        <button @click="back" value="back">
                            <i class="fas fa-undo"></i>
                        </button>
                    </div>
                    <div class="col-4">
                        <button @click="info" value="info">
                            <i class="fas fa-info"></i>
                        </button>
                    </div>
                    <div class="col-4">
                        <button @click="source" value="source">
                            <i class="fas fa-plug"></i>
                        </button>
                    </div>
                </div>
                <div class="row">
                    <div class="col-4">
                        <button @click="menu" value="menu">
                            <i class="fas fa-bars"></i>
                        </button>
                    </div>
                    <div class="col-4">
                        <button @click="tools" value="tools">
                            <i class="fas fa-tools"></i>
                        </button>
                    </div>
                    <div class="col-4">
                        <button @click="browser" value="browser">
                            <i class="fas fa-globe"></i>
                        </button>
                    </div>
                </div>
            </div>

            <div class="volume-channel section">
                <div class="volume col-5">
                    <div class="row">
                        <button @click="volumeUp" value="volume_up">
                            <i class="fas fa-plus"></i>
                        </button>
                    </div>
                    <div class="row">
                        <i class="fas fa-volume-up"></i>
                    </div>
                    <div class="row">
                        <button @click="volumeDown" value="volume_down">
                            <i class="fas fa-minus"></i>
                        </button>
                    </div>
                    <div class="row">
                        <button @click="mute" value="mute">
                            <i class="fas fa-volume-mute"></i>
                        </button>
                    </div>
                </div>

                <div class="col-2">&nbsp;</div>

                <div class="channel col-5">
                    <div class="row">
                        <button @click="channelUp" value="channel_up">
                            <i class="fas fa-plus"></i>
                        </button>
                    </div>
                    <div class="row">
                        CH
                    </div>
                    <div class="row">
                        <button @click="channelDown" value="channel_down">
                            <i class="fas fa-minus"></i>
                        </button>
                    </div>
                    <div class="row">
                        <button @click="channel" value="channel">
                            <i class="fas fa-keyboard"></i>
                        </button>
                    </div>
                </div>
            </div>

            <div class="directions section">
                <div class="row">
                    <div class="col-4">&nbsp;</div>
                    <div class="col-4">
                        <button @click="up" value="up">
                            <i class="fas fa-chevron-up"></i>
                        </button>
                    </div>
                    <div class="col-4">&nbsp;</div>
                </div>

                <div class="row">
                    <div class="col-4">
                        <button @click="left" value="left">
                            <i class="fas fa-chevron-left"></i>
                        </button>
                    </div>
                    <div class="col-4">
                        <button @click="enter" value="enter">
                            <i class="far fa-circle"></i>
                        </button>
                    </div>
                    <div class="col-4">
                        <button @click="right" value="right">
                            <i class="fas fa-chevron-right"></i>
                        </button>
                    </div>
                </div>

                <div class="row">
                    <div class="col-4">&nbsp;</div>
                    <div class="col-4">
                        <button @click="down" value="down">
                            <i class="fas fa-chevron-down"></i>
                        </button>
                    </div>
                    <div class="col-4">&nbsp;</div>
                </div>
            </div>

            <div class="row colors section">
                <div class="col-3">
                    <button class="color red" @click="color" value="red"></button>
                </div>
                <div class="col-3">
                    <button class="color green" @click="color" value="green"></button>
                </div>
                <div class="col-3">
                    <button class="color yellow" @click="color" value="yellow"></button>
                </div>
                <div class="col-3">
                    <button class="color blue" @click="color" value="blue"></button>
                </div>
            </div>
        </div>
    </div>
</script>

