<script type="text/javascript" src="{{ url_for('static', filename='js/plugins/camera/index.js') }}"></script>

<script type="text/x-template" id="tmpl-camera-ir-mlx90640">
    {% include 'plugins/camera/index.html' %}
</script>

