<script type="text/x-template" id="tmpl-widget">
    <div class="widget" :class="['col-' + (config.columns || 12), 'row-' + (config.rows || 1)]">
        <component :is="tag" :config="config"></component>
    </div>
</script>

